package cz.moneta.test.regression.commercial.auto.smartauto;

import cz.moneta.test.harness.annotations.JiraTestCase;
import cz.moneta.test.harness.annotations.TestCase;
import cz.moneta.test.harness.annotations.TestScenario;
import cz.moneta.test.regression.commercial.auto.smartauto.mockdata.TrailerMock;
import org.junit.jupiter.api.Disabled;

@Disabled
@TestScenario(name = "Successful filled new calculation for trailer.")
public class CalculationTrailerTest extends AbstractTest {

    /*
     * CONSUMER
     */
    @JiraTestCase(id = "LAMD-T1003")
    @TestCase(name = "Commodity: trailer, Customer: consumer, State: new, Type: O1, Product: autoCREDIT," +
            "Product Type: Standard, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationTrailer1() {
        trailerTasks(TrailerMock.PrepareCalculationTrailer1());
    }

    @JiraTestCase(id = "LAMD-T1004")
    @TestCase(name = "Commodity: trailer, Customer: consumer, State: new, Type: O1, Product: autoCREDIT," +
            "Product Type: Standard, VAT: yes, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationTrailer1_1() {
        trailerTasks(TrailerMock.PrepareCalculationTrailer1_1());
    }

    @JiraTestCase(id = "LAMD-T1005")
    @TestCase(name = "Commodity: trailer, Customer: consumer, State: new, Type: O1, Product: autoCREDIT," +
            "Product Type: C2C, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationTrailer2() {
        trailerTasks(TrailerMock.PrepareCalculationTrailer2());
    }

    /*
     * PLACEHOLDER FOR TC 3 BACK LOAN CONSUMER NEW - NOT SELLING AT THIS MOMENT
     */
    @JiraTestCase(id = "LAMD-T1006")
    @TestCase(name = "Commodity: trailer, Customer: consumer, State: used, Type: O1, Product: autoCREDIT," +
            "Product Type: Standard, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationTrailer4() {
        trailerTasks(TrailerMock.PrepareCalculationTrailer4());
    }

    @JiraTestCase(id = "LAMD-T1007")
    @TestCase(name = "Commodity: trailer, Customer: consumer, State: used, Type: O1, Product: autoCREDIT," +
            "Product Type: C2C, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationTrailer5() {
        trailerTasks(TrailerMock.PrepareCalculationTrailer5());
    }

    /*
     * PLACEHOLDER FOR TC 6 BACK LOAN CONSUMER USED - NOT SELLING AT THIS MOMENT
     */

    /*
     * BUSINESSMAN WITHOUT VAT
     */
    @JiraTestCase(id = "LAMD-T1008")
    @TestCase(name = "Commodity: trailer, Customer: businessman without vat, State: new, Type: O1, Product: autoCREDIT," +
            "Product Type: Standard, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationTrailer7() {
        trailerTasks(TrailerMock.PrepareCalculationTrailer7());
    }

    @JiraTestCase(id = "LAMD-T1009")
    @TestCase(name = "Commodity: trailer, Customer: businessman without vat, State: new, Type: O1, Product: autoCREDIT," +
            "Product Type: C2C, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationTrailer8() {
        trailerTasks(TrailerMock.PrepareCalculationTrailer8());
    }

    @JiraTestCase(id = "LAMD-T1010")
    @TestCase(name = "Commodity: trailer, Customer: businessman without vat, State: new, Type: O1, Product: autoCREDIT," +
            "Product Type: Back loan, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationTrailer9() {
        trailerTasks(TrailerMock.PrepareCalculationTrailer9());
    }

    @JiraTestCase(id = "LAMD-T1011")
    @TestCase(name = "Commodity: trailer, Customer: businessman without vat, State: used, Type: O1, Product: autoCREDIT," +
            "Product Type: Standard, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationTrailer10() {
        trailerTasks(TrailerMock.PrepareCalculationTrailer10());
    }

    @JiraTestCase(id = "LAMD-T1012")
    @TestCase(name = "Commodity: trailer, Customer: businessman without vat, State: used, Type: O1, Product: autoCREDIT," +
            "Product Type: C2C, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationTrailer11() {
        trailerTasks(TrailerMock.PrepareCalculationTrailer11());
    }

    @JiraTestCase(id = "LAMD-T1013")
    @TestCase(name = "Commodity: trailer, Customer: businessman without vat, State: used, Type: O1, Product: autoCREDIT," +
            "Product Type: Back loan, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationTrailer12() {
        trailerTasks(TrailerMock.PrepareCalculationTrailer12());
    }
}